@@ -9,15 +9,25 @@
 # under the terms of the GNU General Public License, version 2 or later.
 # No warranty expressed or implied. See the file LICENSE for details.
 
-""" Scenario adaptor for nose tests
+""" test scenario adaptation plugin for nose
 
-    Adapt parameterised test cases with scenario data, generating
-    unique test cases for each scenario.
+    The 'scenario' plugin for 'nose' enables any test case to be
+    transformed into multiple copies of that test, each adapted for a
+    specific test scenario.
+
+    The plugin will detect scenarios associated with one or more test
+    cases. It then generates a number of adapted copies of each test
+    case, one for each scenario, with the scenario data exposed to the
+    test case via attributes. Each adapted test case will then be run
+    separately by 'nose', and will be identified distinctly by the
+    scenario used.
+
+    'nose' is a testing framework for Python code.
 
     """
 
-_version = "0.1"
-_date = "2008-07-17"
+_version = "0.1.1"
+_date = "2008-07-18"
 _author_name = "Ben Finney"
 _author_email = "ben+python@benfinney.id.au"
 _author = "%(_author_name)s <%(_author_email)s>" % vars()
